==> paraview-v0.5.0.zip: paraview-v0.5.0/Remoting/Microservices/Testing/Python/TestPipelineBuilderWithRendering.py <==
import asyncio

from parat.services import ParaT, PipelineBuilder, PropertyManager
import vtk
import sys


async def main():
    App = ParaT()
    session = await App.initialize()

    builder = PipelineBuilder(session)

    sphere = await builder.CreateSource(
        "sources", "SphereSource", ThetaResolution=80, Radius=2
    )
    shrink = await builder.CreateFilter(
        "filters", "ShrinkFilter", Input=sphere, ShrinkFactor=0.3
    )

    pmanager = PropertyManager()
    pmanager.SetValues(sphere, Radius=3, Center=[1, 2, 3], EndPhi=90)

    await asyncio.sleep(0.1)

    view = await builder.CreateView("views", "RenderView")

    representation = await builder.CreateRepresentation(
        shrink, 0, view, "GeometryRepresentation"
    )

    await pmanager.Update(view)
    view.ResetCameraUsingVisiblePropBounds()

    if "-I" in sys.argv:
        iren = vtk.vtkRenderWindowInteractor()
        iren.SetRenderWindow(view.GetRenderWindow())
        iren.Initialize()
        while not iren.GetDone():
            iren.ProcessEvents()
            await asyncio.sleep(0.01)
            if iren.GetKeyCode() == "s":
                pmanager.SetVisibility(representation, view, True)
            if iren.GetKeyCode() == "h":
                pmanager.SetVisibility(representation, view, False)
    else:
        for i in range(5):
            view.GetCamera().Azimuth(10)
            view.StillRender()
            await asyncio.sleep(0.1)

    status = await builder.DeleteProxy(shrink)
    assert status == True

    await App.finalize()


asyncio.run(main())

==> paraview-0.6.0.zip: paraview-0.6.0/Remoting/Microservices/Testing/Python/TestPipelineBuilderWithRendering.py <==
import asyncio

from parat.services import ParaT, PipelineBuilder, PropertyManager
import vtk
import sys


async def main():
    App = ParaT()
    session = await App.initialize()

    builder = PipelineBuilder(session)

    sphere = await builder.CreateSource(
        "sources", "SphereSource", ThetaResolution=80, Radius=2
    )
    shrink = await builder.CreateFilter(
        "filters", "ShrinkFilter", Input=sphere, ShrinkFactor=0.3
    )

    pmanager = PropertyManager()
    pmanager.SetValues(sphere, Radius=3, Center=[1, 2, 3], EndPhi=90)

    await asyncio.sleep(0.1)

    view = await builder.CreateView("views", "RenderView")
    values = pmanager.GetValues(view)

    # make sure ProxyProperties with nullptr as default value are transformed to None
    assert values["BackgroundTexture"] is None

    representation = await builder.CreateRepresentation(
        shrink, 0, view, "GeometryRepresentation"
    )

    await pmanager.Update(view)
    view.ResetCameraUsingVisiblePropBounds()

    if "-I" in sys.argv:
        iren = vtk.vtkRenderWindowInteractor()
        iren.SetRenderWindow(view.GetRenderWindow())
        iren.Initialize()
        while not iren.GetDone():
            iren.ProcessEvents()
            await asyncio.sleep(0.01)
            if iren.GetKeyCode() == "s":
                pmanager.SetVisibility(representation, view, True)
            if iren.GetKeyCode() == "h":
                pmanager.SetVisibility(representation, view, False)
    else:
        for i in range(5):
            view.GetCamera().Azimuth(10)
            view.StillRender()
            await asyncio.sleep(0.1)

    status = await builder.DeleteProxy(shrink)
    assert status == True

    await App.finalize()


asyncio.run(main())
